==> haskell-test-framework-0.8.2.0-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework
version: 0.8.2.0
id: test-framework-0.8.2.0-Kw9JrwBTWdAJO9hYgX4lSm
key: test-framework-0.8.2.0-Kw9JrwBTWdAJO9hYgX4lSm
license: BSD-3-Clause
maintainer: Libraries List <libraries@haskell.org>
author: Max Bolingbroke <batterseapower@hotmail.com>
homepage: http://haskell.github.io/test-framework/
synopsis: Framework for running and organising tests, with HUnit and QuickCheck support
description:
    Allows tests such as QuickCheck properties and HUnit test cases to be assembled into test groups, run in
    parallel (but reported in deterministic order, to aid diff interpretation) and filtered and controlled by
    command line options. All of this comes with colored test output, progress reporting and test statistics output.
category: Testing
abi: c443a2c16013e8d4c56e85975d499f36
exposed: True
exposed-modules:
    Test.Framework Test.Framework.Options Test.Framework.Providers.API
    Test.Framework.Runners.API Test.Framework.Runners.Console
    Test.Framework.Runners.Options Test.Framework.Runners.TestPattern
    Test.Framework.Seed
hidden-modules: Test.Framework.Core Test.Framework.Improving
                Test.Framework.Runners.Console.Colors
                Test.Framework.Runners.Console.ProgressBar
                Test.Framework.Runners.Console.Run
                Test.Framework.Runners.Console.Statistics
                Test.Framework.Runners.Console.Table
                Test.Framework.Runners.Console.Utilities
                Test.Framework.Runners.Core Test.Framework.Runners.Processors
                Test.Framework.Runners.Statistics Test.Framework.Runners.ThreadPool
                Test.Framework.Runners.TimedConsumption
                Test.Framework.Runners.XML.JUnitWriter Test.Framework.Runners.XML
                Test.Framework.Utilities
import-dirs: /usr/lib/ghc-8.6.5/site-local/test-framework-0.8.2.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/test-framework-0.8.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/test-framework-0.8.2.0
hs-libraries: HStest-framework-0.8.2.0-Kw9JrwBTWdAJO9hYgX4lSm
depends:
    ansi-terminal-0.9.1-4EGEPOXIA9UHNrgfDydiTP
    ansi-wl-pprint-0.6.9-2omI3jlOeR11cioOWuwupk base-4.12.0.0
    containers-0.6.0.1 hostname-1.0-96RwzZJKf0mHYnt0kjXkqR
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    regex-posix-0.95.2-jmiKTXBn5tB7yYph2GqnC time-1.8.0.2
    xml-1.3.14-ESp8cJy4XJ8BJKfvGeNymT
haddock-interfaces: /usr/share/doc/haskell-test-framework/html/test-framework.haddock
haddock-html: /usr/share/doc/haskell-test-framework/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-0.8.2.0-30-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework
version: 0.8.2.0
id: test-framework-0.8.2.0-6VNxYg0rOQvC6zSsMyV1CA
key: test-framework-0.8.2.0-6VNxYg0rOQvC6zSsMyV1CA
license: BSD-3-Clause
maintainer: Libraries List <libraries@haskell.org>
author: Max Bolingbroke <batterseapower@hotmail.com>
homepage: http://haskell.github.io/test-framework/
synopsis: Framework for running and organising tests, with HUnit and QuickCheck support
description:
    Allows tests such as QuickCheck properties and HUnit test cases to be assembled into test groups, run in
    parallel (but reported in deterministic order, to aid diff interpretation) and filtered and controlled by
    command line options. All of this comes with colored test output, progress reporting and test statistics output.
category: Testing
abi: f3fb867b1aa172162a07086c79d38b6f
exposed: True
exposed-modules:
    Test.Framework Test.Framework.Options Test.Framework.Providers.API
    Test.Framework.Runners.API Test.Framework.Runners.Console
    Test.Framework.Runners.Options Test.Framework.Runners.TestPattern
    Test.Framework.Seed
hidden-modules: Test.Framework.Core Test.Framework.Improving
                Test.Framework.Runners.Console.Colors
                Test.Framework.Runners.Console.ProgressBar
                Test.Framework.Runners.Console.Run
                Test.Framework.Runners.Console.Statistics
                Test.Framework.Runners.Console.Table
                Test.Framework.Runners.Console.Utilities
                Test.Framework.Runners.Core Test.Framework.Runners.Processors
                Test.Framework.Runners.Statistics Test.Framework.Runners.ThreadPool
                Test.Framework.Runners.TimedConsumption
                Test.Framework.Runners.XML.JUnitWriter Test.Framework.Runners.XML
                Test.Framework.Utilities
import-dirs: /usr/lib/ghc-8.6.5/site-local/test-framework-0.8.2.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/test-framework-0.8.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/test-framework-0.8.2.0
hs-libraries: HStest-framework-0.8.2.0-6VNxYg0rOQvC6zSsMyV1CA
depends:
    ansi-terminal-0.9.1-7greAUREMxf1pgDTp3Pb1X
    ansi-wl-pprint-0.6.9-3Xg3e4uL5WT2lDxJKMbjez base-4.12.0.0
    containers-0.6.0.1 hostname-1.0-96RwzZJKf0mHYnt0kjXkqR
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    regex-posix-0.95.2-jmiKTXBn5tB7yYph2GqnC time-1.8.0.2
    xml-1.3.14-ESp8cJy4XJ8BJKfvGeNymT
haddock-interfaces: /usr/share/doc/haskell-test-framework/html/test-framework.haddock
haddock-html: /usr/share/doc/haskell-test-framework/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
